@@ -1,6 +1,4 @@
-from ..transformersx_base import *
-from .tasks import *
-from .. import *
+from ai_transformersx.examples.example_base import ExampleTaskBase, ComplexArguments, log
 
 
 class ExampleManagement():
